
#ifndef _C10_kl461_
#define _C10_kl461_

#ifdef __cplusplus
extern "C" {
#endif

RTOSHF (EIF_REFERENCE,8543)
static EIF_REFERENCE F1164_8543_body(EIF_REFERENCE);
extern EIF_REFERENCE F1164_8543(EIF_REFERENCE);
extern void EIF_Minit461(void);

#ifdef __cplusplus
}
#endif

#endif
